Crate mongo_es

Crate mongo_es 

Structs

Client
This is the main entry point for the API. A Client is used to connect to a MongoDB cluster. By default, it will monitor the topology of the cluster, keeping track of any changes, such as servers being added or removed.
MongoEventRepository
An event repository using MongoDB for persistence.
MongoViewRepository

Functions

default_mongo_client
mongo_cqrs

Type Aliases

MongoCqrs