Structs
- Client
- This is the main entry point for the API. A
Clientis used to connect to a MongoDB cluster. By default, it will monitor the topology of the cluster, keeping track of any changes, such as servers being added or removed. - Mongo
Event Repository - An event repository using MongoDB for persistence.
- Mongo
View Repository